# Gridlock - a collection of grid-based strategy games
# Copyright (c) 2009 Brian Nenninger (brian@dozingcatsoftware.com)
# Gridlock comes with ABSOLUTELY NO WARRANTY, and is released under version 3 of the GNU GPL.

import PGOpenGLUtils
import Chess
import Preferences

# use circles for non-king pieces to indicate movement directions
blobs = {Chess.PAWN:   ((0,0),),
         Chess.KNIGHT: ((0,-0.5), (0,0), (0,0.5), (0.5,0.5)),
         Chess.BISHOP: ((0,0), (-0.5,-0.5), (0.5,0.5), (-0.5,0.5), (0.5,-0.5)),
         Chess.ROOK:   ((0,0), (0.5,0), (-0.5,0), (0,0.5), (0,-0.5)),
         Chess.QUEEN:  ((0,0), (0.5,0), (-0.5,0), (0,0.5), (0,-0.5), (-0.5,-0.5), (0.5,0.5), (-0.5,0.5), (0.5,-0.5)),
}

def drawCell(state, coord, value, scale):
    absval = abs(value)
    if absval==0: return False
    pnum = 1 if value>0 else 2
    color = Preferences.prefs.player_color(pnum, as_float=True)
    if absval in blobs:
        # use fixed 0.2 size for blobs
        b = ( (blob, 0.2) for blob in blobs[absval] )
        PGOpenGLUtils.draw_blobs(coord, b, scale=scale, height=0.8, color=color, detail=10)
    else:
        # assume king, draw big piece, invert color if king is in check
        if Chess.is_position_attackable(state.grid, coord, state.next_player()):
            color = [1-x for x in color]
        PGOpenGLUtils.draw_cylinder(scale=scale, color=color)
    return True
